import * as svelte_store from 'svelte/store';

interface Labelable {
    label?: string;
}

interface Pressable {
    pressed: boolean;
}

interface Button extends Pressable, Labelable {
}
declare function createButton(init?: Partial<Button>): {
    subscribe: (this: void, run: svelte_store.Subscriber<{
        pressed: boolean;
    }>, invalidate?: ((value?: {
        pressed: boolean;
    } | undefined) => void) | undefined) => svelte_store.Unsubscriber;
    button: (node: HTMLElement) => {
        destroy: () => void;
    };
};

interface Controllable {
    controls?: string;
}

interface Expandable {
    expanded: boolean;
    opened: boolean;
}

interface Selectable {
    selected: any;
}

interface ItemOptions {
    value?: any;
    disabled?: boolean;
}
interface ListItem {
    id: string;
    value: any;
    disabled: boolean;
}
interface List {
    items: ListItem[];
    active: number;
}

interface Combobox extends Labelable, Expandable, Controllable, List, Selectable {
    input?: HTMLElement;
    filter: string;
    moved: boolean;
}
declare function createCombobox(init?: Partial<Combobox>): {
    subscribe: (this: void, run: svelte_store.Subscriber<{
        expanded: boolean;
        selected: any;
        filter: string;
        active: any;
    }>, invalidate?: ((value?: {
        expanded: boolean;
        selected: any;
        filter: string;
        active: any;
    } | undefined) => void) | undefined) => svelte_store.Unsubscriber;
    input: (node: HTMLElement) => {
        destroy: () => void;
    };
    button: (node: HTMLElement) => {
        destroy: () => void;
    };
    items: (node: HTMLElement) => {
        destroy: () => void;
    };
    item: (node: HTMLElement, options?: ItemOptions) => {
        update: (options?: ItemOptions | undefined) => void;
        destroy: () => void;
    };
    reset: () => void;
    open: () => void;
    close: () => void;
};

interface Dialog extends Expandable, Labelable {
}
declare function createDialog(init?: Partial<Dialog>): {
    subscribe: (this: void, run: svelte_store.Subscriber<{
        expanded: boolean;
    }>, invalidate?: ((value?: {
        expanded: boolean;
    } | undefined) => void) | undefined) => svelte_store.Unsubscriber;
    modal: (node: HTMLElement) => {
        destroy: () => void;
    };
    open: () => void;
    close: () => void;
};

interface Disclosure extends Labelable, Expandable, Controllable {
    button?: string;
    panel?: string;
}
declare function createDisclosure(init?: Partial<Disclosure>): {
    subscribe: (this: void, run: svelte_store.Subscriber<{
        expanded: boolean;
    }>, invalidate?: ((value?: {
        expanded: boolean;
    } | undefined) => void) | undefined) => svelte_store.Unsubscriber;
    button: (node: HTMLElement) => {
        destroy: () => void;
    };
    panel: (node: HTMLElement) => {
        destroy: () => void;
    };
    open: () => void;
    close: () => void;
};

interface Listbox extends Labelable, Expandable, Controllable, List, Selectable {
    button?: HTMLElement;
}
declare function createListbox<T = any>(init?: Partial<Listbox>): {
    subscribe: (this: void, run: svelte_store.Subscriber<{
        expanded: boolean;
        selected: any;
        active: any;
    }>, invalidate?: ((value?: {
        expanded: boolean;
        selected: any;
        active: any;
    } | undefined) => void) | undefined) => svelte_store.Unsubscriber;
    button: (node: HTMLElement) => {
        destroy: () => void;
    };
    items: (node: HTMLElement) => {
        destroy: () => void;
    };
    item: (node: HTMLElement, options?: ItemOptions) => {
        update: (options?: ItemOptions | undefined) => void;
        destroy: () => void;
    };
    open: () => void;
    close: () => void;
};

interface Menu extends Labelable, Expandable, Controllable, List, Selectable {
    button?: HTMLElement;
}
declare function createMenu(init?: Partial<Menu>): {
    subscribe: (this: void, run: svelte_store.Subscriber<{
        expanded: boolean;
        active: any;
    }>, invalidate?: ((value?: {
        expanded: boolean;
        active: any;
    } | undefined) => void) | undefined) => svelte_store.Unsubscriber;
    button: (node: HTMLElement) => {
        destroy: () => void;
    };
    items: (node: HTMLElement) => {
        destroy: () => void;
    };
    item: (node: HTMLElement, options?: ItemOptions) => {
        update: (options?: ItemOptions | undefined) => void;
        destroy: () => void;
    };
    open: () => void;
    close: () => void;
};

interface Popover extends Labelable, Expandable, Controllable {
    button?: string;
    panel?: string;
}
declare function createPopover(init?: Partial<Popover>): {
    subscribe: (this: void, run: svelte_store.Subscriber<{
        expanded: boolean;
    }>, invalidate?: ((value?: {
        expanded: boolean;
    } | undefined) => void) | undefined) => svelte_store.Unsubscriber;
    button: (node: HTMLElement) => {
        destroy: () => void;
    };
    panel: (node: HTMLElement) => {
        destroy: () => void;
    };
    open: () => void;
    close: () => void;
};

export { Button, Combobox, Dialog, Disclosure, Listbox, Menu, Popover, createButton, createCombobox, createDialog, createDisclosure, createListbox, createMenu, createPopover };
